[java-shib-profile] branch main updated: JSPROF-14 Tolerate gaps in resource-related module properties

Codeberg noreply at shibboleth.net
Fri Sep 18 12:14:33 UTC 2026


This is an automated email from the git hooks/post-receive script.

codeberg pushed a commit to branch main
in repository java-shib-profile.

View the commit online:
https://codeberg.org/Shibboleth/java-shib-profile/commit/8a05c7d157b3956073c1ed92b4a4c4944eddb3b6

The following commit(s) were added to refs/heads/main by this push:
     new 8a05c7d  JSPROF-14 Tolerate gaps in resource-related module properties
8a05c7d is described below

commit 8a05c7d157b3956073c1ed92b4a4c4944eddb3b6
Author: Rod Widdowson <rdw at steadingsoftware.com>
AuthorDate: Fri Sep 18 13:14:33 2026 +0100

    JSPROF-14 Tolerate gaps in resource-related module properties
    
    https://shibboleth.atlassian.net/browse/JSPROF-14
    
    Add new support function to enumerate all the plugins in
    plugins.properties.  Plus a test
---
 .../InstallableComponentSupport.java               |  31 +-
 .../InstallableComponentTests.java                 |  19 +-
 .../installablecomponent/allPlugins.properties     | 528 +++++++++++++++++++++
 3 files changed, 569 insertions(+), 9 deletions(-)

diff --git a/shib-profile-api/src/test/java/net/shibboleth/profile/installablecomponent/InstallableComponentTests.java b/shib-profile-api/src/test/java/net/shibboleth/profile/installablecomponent/InstallableComponentTests.java
index 62ae765..dcecd49 100644
--- a/shib-profile-api/src/test/java/net/shibboleth/profile/installablecomponent/InstallableComponentTests.java
+++ b/shib-profile-api/src/test/java/net/shibboleth/profile/installablecomponent/InstallableComponentTests.java
@@ -34,8 +34,6 @@ import org.testng.annotations.Test;
 import net.shibboleth.shared.collection.CollectionSupport;
 import net.shibboleth.shared.primitive.StringSupport;
 
-
-
 /**
  * Tests for {@link InstallableComponentInfo} and {@link InstallableComponentSupport}
  */
@@ -62,8 +60,6 @@ public class InstallableComponentTests {
     }
 
     @Test(dependsOnMethods = {"testLoadProperties"}) final void testParseInfo() {
-
-        // add the version string
         final String versionsAsString = "1.0.0 1.0.1 1.0.2 2.0.0 2.1.0 2.2.0 2.3.0 2.3.1 2.3.2";
         info = new TestInstallableComponent();
         assertTrue(info.isInfoComplete());
@@ -76,7 +72,6 @@ public class InstallableComponentTests {
     }
     
     @Test(dependsOnMethods = {"testParseInfo"}) final void testGetBestVersion() {
-        
         InstallableComponentVersion best = InstallableComponentSupport.
                 getBestVersion(new InstallableComponentVersion(4, 2, 0), 
                         new InstallableComponentVersion(1, 0, 0),
@@ -89,11 +84,23 @@ public class InstallableComponentTests {
         assertEquals(best, new InstallableComponentVersion(2,3,2));
     }
 
+    @Test public void allComponentsTest() throws IOException {
+        final ClassPathResource inputAsResource = new ClassPathResource("net/shibboleth/profile/installablecomponent/allPlugins.properties");
+        final String inputAsFQP = inputAsResource.getFile().getAbsolutePath();
+        final Properties allPlugins =
+                InstallableComponentSupport.loadInfo(CollectionSupport.singletonList(new URL("file:///" + inputAsFQP)),  null, null);
+        final List<String> pluginsIds = InstallableComponentSupport.getAllComponents(allPlugins);
+
+        assertEquals(pluginsIds.size(), 13);
+        assertTrue(pluginsIds.contains("net.shibboleth.idp.plugin.jetty"));
+        assertTrue(pluginsIds.contains("net.shibboleth.idp.plugin.rhino"));
+        assertFalse(pluginsIds.contains("nibble.a.happy.warthog"));
+    }
+
     /**
      * Based on the PluginInfo.
      */
     private class TestInstallableComponent extends InstallableComponentInfo {
-
         /**  Constructor. */
         public TestInstallableComponent() {
             super(PLUGIN_NAME, properties);
diff --git a/shib-profile-api/src/test/resources/net/shibboleth/profile/installablecomponent/allPlugins.properties b/shib-profile-api/src/test/resources/net/shibboleth/profile/installablecomponent/allPlugins.properties
new file mode 100644
index 0000000..6f07b57
--- /dev/null
+++ b/shib-profile-api/src/test/resources/net/shibboleth/profile/installablecomponent/allPlugins.properties
@@ -0,0 +1,528 @@
+# Derived from a snapshot of plugins.properties
+
+
+#######################
+# TOTP Authentication #
+#######################
+#net.shibboleth.idp.plugin.authn.totp.versions = 1.0.0 1.0.1 1.0.2 2.0.0 2.1.0 2.2.0 2.3.0 2.3.1 2.3.2
+
+net.shibboleth.idp.plugin.authn.totp.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/totp/%{version}
+net.shibboleth.idp.plugin.authn.totp.baseName.%{version} = idp-plugin-totp-dist-%{version}
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.1.0.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.1.0.0 = 4.1.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.1.0.1 = 4.2.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.1.0.1 = 4.2.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.1.0.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.1.0.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.1.0.2 = 4.2.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.1.0.2 = Current
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.0.0 = Withdrawn
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.2.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.2.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.3.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.3.0 = Withdrawn
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.3.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.3.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.3.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.totp.idpVersionMax.2.3.2 = 6.0.0
+net.shibboleth.idp.plugin.authn.totp.idpVersionMin.2.3.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.totp.supportLevel.2.3.2 = Current
+
+
+#######################
+# SCRIPTING Plugins   #
+#######################
+#net.shibboleth.idp.plugin.nashorn.versions= 1.0.0 1.1.0 2.0.0
+
+net.shibboleth.idp.plugin.nashorn.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/scripting/%{version}
+net.shibboleth.idp.plugin.nashorn.baseName.%{version} = idp-plugin-nashorn-jdk-dist-%{version}
+
+net.shibboleth.idp.plugin.nashorn.downloadURL.1.0.0 = https://shibboleth.net/downloads/identity-provider/plugins/scripting/1.0.0
+net.shibboleth.idp.plugin.nashorn.baseName.1.0.0 = idp-plugin-nashorn-dist-1.0.0
+net.shibboleth.idp.plugin.nashorn.idpVersionMax.1.0.0= 5.0.0
+net.shibboleth.idp.plugin.nashorn.idpVersionMin.1.0.0= 4.1.0
+net.shibboleth.idp.plugin.nashorn.supportLevel.1.0.0 = Withdrawn
+
+net.shibboleth.idp.plugin.nashorn.idpVersionMax.1.1.0= 5.0.0
+net.shibboleth.idp.plugin.nashorn.idpVersionMin.1.1.0= 4.1.0
+net.shibboleth.idp.plugin.nashorn.supportLevel.1.1.0 = Current
+
+net.shibboleth.idp.plugin.nashorn.idpVersionMax.2.0.0= 6.0.0
+net.shibboleth.idp.plugin.nashorn.idpVersionMin.2.0.0= 5.0.0
+net.shibboleth.idp.plugin.nashorn.supportLevel.2.0.0 = Current
+
+net.shibboleth.idp.plugin.rhino.versions= 1.0.0 1.1.0 2.0.0 2.1.0
+net.shibboleth.idp.plugin.rhino.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/scripting/%{version}
+net.shibboleth.idp.plugin.rhino.baseName.%{version} = idp-plugin-rhino-dist-%{version}
+
+net.shibboleth.idp.plugin.rhino.idpVersionMax.1.0.0= 5.0.0
+net.shibboleth.idp.plugin.rhino.idpVersionMin.1.0.0= 4.1.0
+net.shibboleth.idp.plugin.rhino.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.rhino.idpVersionMax.1.1.0= 5.0.0
+net.shibboleth.idp.plugin.rhino.idpVersionMin.1.1.0= 4.1.0
+net.shibboleth.idp.plugin.rhino.supportLevel.1.1.0 = Current
+
+net.shibboleth.idp.plugin.rhino.idpVersionMax.2.0.0= 6.0.0
+net.shibboleth.idp.plugin.rhino.idpVersionMin.2.0.0= 5.0.0
+net.shibboleth.idp.plugin.rhino.supportLevel.2.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.rhino.idpVersionMax.2.1.0= 6.0.0
+net.shibboleth.idp.plugin.rhino.idpVersionMin.2.1.0= 5.0.0
+net.shibboleth.idp.plugin.rhino.supportLevel.2.1.0 = Current
+
+################################################################
+# DuoOIDC Authentication based on the Shibboleth Nimbus client #
+################################################################
+#net.shibboleth.idp.plugin.authn.duo.nimbus.versions = 1.0.0 1.1.0 1.1.1 1.2.0 1.3.0 1.4.0 1.4.1 2.0.0 2.1.0 2.2.1 2.2.2 2.3.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/duo-oidc/%{version}
+net.shibboleth.idp.plugin.authn.duo.nimbus.baseName.%{version} = idp-plugin-duo-nimbus-dist-%{version}
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.0.0 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.0.0 = 4.1.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.0.0 = Current
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.1.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.1.0 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.1.1 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.1.1 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.1.1 = Current
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.2.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.2.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.3.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.3.0 = Current
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.4.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.4.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.4.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.1.4.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.1.4.1 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.1.4.1 = Current
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.2.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.2.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.2.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.2.2.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.2.2.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.2.2.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.2.2.2 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.2.2.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.2.2.2 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMax.2.3.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.idpVersionMin.2.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.nimbus.supportLevel.2.3.0 = Current
+
+#####################################################
+# DuoOIDC Authentication based on the Duo WebSDK v4 #
+#####################################################
+#net.shibboleth.idp.plugin.authn.duo.sdk.versions = 1.0.0 1.1.0 1.1.1 1.2.0 1.3.0 1.4.0 1.4.1 2.0.0 2.1.0 2.2.1 2.2.2 2.3.0
+net.shibboleth.idp.plugin.authn.duo.sdk.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/duo-oidc/%{version}
+net.shibboleth.idp.plugin.authn.duo.sdk.baseName.%{version} = idp-plugin-duo-sdk-dist-%{version}
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.0.0 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.0.0 = 4.1.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.0.0 = Current
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.1.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.1.0 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.1.1 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.1.1 = 4.1.1
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.1.1 = Current
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.2.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.2.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.3.0 = 4.2.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.3.0 = Current
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.4.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.4.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.4.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.1.4.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.1.4.1 = 4.3.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.1.4.1 = Current
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.2.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.2.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.2.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.2.2.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.2.2.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.2.2.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.2.2.2 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.2.2.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.2.2.2 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMax.2.3.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.idpVersionMin.2.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.duo.sdk.supportLevel.2.3.0 = Current
+
+###############################
+# OIDC Commons library plugin #
+###############################
+#net.shibboleth.oidc.common.versions = 1.0.0 1.1.0 2.0.0 2.1.0 2.2.0 2.2.1 3.0.0 3.0.1 3.1.0 3.1.1 3.2.0 3.3.0 3.3.1
+net.shibboleth.oidc.common.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/oidc-common/%{version}
+net.shibboleth.oidc.common.baseName.%{version} = oidc-common-dist-%{version}
+
+net.shibboleth.oidc.common.idpVersionMax.1.0.0 = 5.0.0
+net.shibboleth.oidc.common.idpVersionMin.1.0.0 = 4.1.0
+net.shibboleth.oidc.common.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.1.1.0 = 4.2.0
+net.shibboleth.oidc.common.idpVersionMin.1.1.0 = 4.1.0
+net.shibboleth.oidc.common.supportLevel.1.1.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.2.0.0 = 5.0.0
+net.shibboleth.oidc.common.idpVersionMin.2.0.0 = 4.2.0
+net.shibboleth.oidc.common.supportLevel.2.0.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.2.1.0 = 5.0.0
+net.shibboleth.oidc.common.idpVersionMin.2.1.0 = 4.2.0
+net.shibboleth.oidc.common.supportLevel.2.1.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.2.2.0 = 5.0.0
+net.shibboleth.oidc.common.idpVersionMin.2.2.0 = 4.3.0
+net.shibboleth.oidc.common.supportLevel.2.2.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.2.2.1 = 5.0.0
+net.shibboleth.oidc.common.idpVersionMin.2.2.1 = 4.3.0
+net.shibboleth.oidc.common.supportLevel.2.2.1 = Current
+
+net.shibboleth.oidc.common.idpVersionMax.3.0.0 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.0.0 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.0.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.0.1 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.0.1 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.0.1 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.1.0 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.1.0 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.1.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.1.1 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.1.1 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.1.1 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.2.0 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.2.0 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.2.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.3.0 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.3.0 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.3.0 = OutOfDate
+
+net.shibboleth.oidc.common.idpVersionMax.3.3.1 = 6.0.0
+net.shibboleth.oidc.common.idpVersionMin.3.3.1 = 5.0.0
+net.shibboleth.oidc.common.supportLevel.3.3.1 = Current
+
+##################################
+# OpenID Connect Provider plugin #
+##################################
+#net.shibboleth.idp.plugin.oidc.op.versions = 3.0.0 3.0.1 3.0.2 3.0.3 3.0.4 3.1.0 3.1.1 3.1.2 3.2.0 3.2.1 3.3.0 3.4.0 4.0.0 4.1.0 4.2.0 4.2.1 4.3.0 4.3.1
+net.shibboleth.idp.plugin.oidc.op.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/oidc-op/%{version}
+net.shibboleth.idp.plugin.oidc.op.baseName.%{version} = idp-plugin-oidc-op-distribution-%{version}
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.0.0 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.0.0 = 4.1.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.0.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.0.1 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.0.1 = 4.1.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.0.1 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.0.2 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.0.2 = 4.1.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.0.2 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.0.3 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.0.3 = 4.1.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.0.3 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.0.4 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.0.4 = 4.1.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.0.4 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.1.0 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.1.0 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.1.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.1.1 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.1.1 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.1.1 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.1.2 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.1.2 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.1.2 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.2.0 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.2.0 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.2.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.2.1 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.2.1 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.2.1 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.3.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.3.0 = 4.2.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.3.0 = Secadv
+��
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.3.4.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.3.4.0 = 4.3.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.3.4.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.0.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.0.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.0.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.1.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.1.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.1.0 = Secadv
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.2.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.2.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.2.1 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.2.1 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.2.1 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.3.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.3.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.3.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.op.idpVersionMax.4.3.1 = 6.0.0
+net.shibboleth.idp.plugin.oidc.op.idpVersionMin.4.3.1 = 5.0.0
+net.shibboleth.idp.plugin.oidc.op.supportLevel.4.3.1 = Current
+
+##################################
+# METADATA GENERATOR PLUGIN      #
+##################################
+#net.shibboleth.idp.plugin.metadatagen.versions=0.1.1 1.0.0 1.0.1 2.0.0
+net.shibboleth.idp.plugin.metadatagen.baseName.%{version} = idp-plugin-metadatagen-dist-%{version}
+net.shibboleth.idp.plugin.metadatagen.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/metadatagen/%{version}
+
+net.shibboleth.idp.plugin.metadatagen.idpVersionMax.0.1.1 = 5.0.0
+net.shibboleth.idp.plugin.metadatagen.idpVersionMin.0.1.1= 4.1.0
+net.shibboleth.idp.plugin.metadatagen.supportLevel.0.1.1= OutOfDate
+
+net.shibboleth.idp.plugin.metadatagen.idpVersionMax.1.0.0 = 5.0.0
+net.shibboleth.idp.plugin.metadatagen.idpVersionMin.1.0.0= 4.1.0
+net.shibboleth.idp.plugin.metadatagen.supportLevel.1.0.0= OutOfDate
+
+net.shibboleth.idp.plugin.metadatagen.idpVersionMax.1.0.1 = 5.0.0
+net.shibboleth.idp.plugin.metadatagen.idpVersionMin.1.0.1= 4.1.0
+net.shibboleth.idp.plugin.metadatagen.supportLevel.1.0.1= Current
+
+net.shibboleth.idp.plugin.metadatagen.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.metadatagen.idpVersionMin.2.0.0= 5.0.0
+net.shibboleth.idp.plugin.metadatagen.supportLevel.2.0.0= Current
+
+##################################
+# STORAGE SERVICE PLUGIN         #
+##################################
+#net.shibboleth.plugin.storage.jdbc.versions=1.0.0 1.0.1 1.0.2 1.0.3 1.0.4 2.0.0 2.0.1 2.1.0
+net.shibboleth.plugin.storage.jdbc.baseName.%{version} = java-plugin-jdbc-storage-%{version}
+net.shibboleth.plugin.storage.jdbc.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/jdbc/%{version}
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.1.0.0 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.1.0.0= 4.1.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.1.0.0= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.1.0.1 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.1.0.1= 4.1.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.1.0.1= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.1.0.2 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.1.0.2= 4.1.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.1.0.2= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.1.0.3 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.1.0.3= 4.1.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.1.0.3= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.1.0.4 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.1.0.4= 4.1.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.1.0.4= Current
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.2.0.0= 5.0.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.2.0.0= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.2.0.1 = 6.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.2.0.1= 5.0.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.2.0.1= OutOfDate
+
+net.shibboleth.plugin.storage.jdbc.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.plugin.storage.jdbc.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.plugin.storage.jdbc.supportLevel.2.1.0 = Current
+
+###############################
+# OIDC Config plugin          #
+###############################
+#net.shibboleth.idp.plugin.oidc.config.versions = 1.0.0 1.0.1 2.0.0 2.1.0 2.2.0 3.0.0 3.0.1
+net.shibboleth.idp.plugin.oidc.config.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/oidc-config/%{version}
+net.shibboleth.idp.plugin.oidc.config.baseName.%{version} = idp-plugin-oidc-config-dist-%{version}
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.1.0.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.1.0.0 = 4.3.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.1.0.0 = Withdrawn
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.1.0.1 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.1.0.1 = 4.3.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.1.0.1 = Current
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.2.0.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.2.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.2.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.2.2.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.2.2.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.2.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.3.0.0 = 6.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.3.0.0 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.3.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.oidc.config.idpVersionMax.3.0.1 = 6.0.0
+net.shibboleth.idp.plugin.oidc.config.idpVersionMin.3.0.1 = 5.0.0
+net.shibboleth.idp.plugin.oidc.config.supportLevel.3.0.1 = Current
+
+###################################################
+# OIDC Relying Party Proxy-Authentication plugin  #
+###################################################
+#net.shibboleth.idp.plugin.authn.oidc.rp.versions = 1.0.0 1.1.0 2.0.0 2.0.1 2.1.0 2.1.1 2.1.2 2.2.0 2.3.0
+net.shibboleth.idp.plugin.authn.oidc.rp.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/oidc-rp/%{version}
+net.shibboleth.idp.plugin.authn.oidc.rp.baseName.%{version} = idp-plugin-oidc-rp-dist-%{version}
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.1.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.1.0.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.1.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.1.1.0 = 4.3.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.1.1.0 = Current
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.0.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.0.0 = Withdrawn
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.0.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.0.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.0.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.1.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.1.0 = Withdrawn
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.1.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.1.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.1.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.1.2 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.1.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.1.2 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.2.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.2.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMax.2.3.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.idpVersionMin.2.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.oidc.rp.supportLevel.2.3.0 = Current
+
+###################################
+# WebAuthn Authentication plugin  #
+###################################
+#net.shibboleth.idp.plugin.authn.webauthn.versions = 1.0.0 1.1.0 1.2.0 1.3.0 1.4.0 1.4.1 1.4.2
+net.shibboleth.idp.plugin.authn.webauthn.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/webauthn/%{version}
+net.shibboleth.idp.plugin.authn.webauthn.baseName.%{version} = idp-plugin-webauthn-dist-%{version}
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.0.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.0.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.1.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.1.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.1.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.2.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.2.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.2.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.3.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.3.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.3.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.4.0 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.4.0 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.4.0 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.4.1 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.4.1 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.4.1 = OutOfDate
+
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMax.1.4.2 = 6.0.0
+net.shibboleth.idp.plugin.authn.webauthn.idpVersionMin.1.4.2 = 5.0.0
+net.shibboleth.idp.plugin.authn.webauthn.supportLevel.1.4.2 = Current
+
+###################################
+# Jetty plugin  #
+###################################
+#net.shibboleth.idp.plugin.jetty.versions = 1.0.0 1.0.1
+net.shibboleth.idp.plugin.jetty.downloadURL.%{version} = https://shibboleth.net/downloads/identity-provider/plugins/jetty/%{version}
+net.shibboleth.idp.plugin.jetty.baseName.%{version} = jetty-base-plugin-dist-%{version}
+
+net.shibboleth.idp.plugin.jetty.idpVersionMax.1.0.0 = 6.0.0
+net.shibboleth.idp.plugin.jetty.idpVersionMin.1.0.0 = 5.1.0
+net.shibboleth.idp.plugin.jetty.supportLevel.1.0.0 = OutOfDate
+
+net.shibboleth.idp.plugin.jetty.idpVersionMax.1.0.1 = 6.0.0
+net.shibboleth.idp.plugin.jetty.idpVersionMin.1.0.1 = 5.1.0
+net.shibboleth.idp.plugin.jetty.supportLevel.1.0.1 = Current
+

diff --git a/shib-profile-api/src/main/java/net/shibboleth/profile/installablecomponent/InstallableComponentSupport.java b/shib-profile-api/src/main/java/net/shibboleth/profile/installablecomponent/InstallableComponentSupport.java
index c705526..f6c64ad 100644
--- a/shib-profile-api/src/main/java/net/shibboleth/profile/installablecomponent/InstallableComponentSupport.java
+++ b/shib-profile-api/src/main/java/net/shibboleth/profile/installablecomponent/InstallableComponentSupport.java
@@ -17,8 +17,10 @@ package net.shibboleth.profile.installablecomponent;
 import java.io.IOException;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Properties;
+import java.util.Set;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
@@ -32,6 +34,7 @@ import org.springframework.core.io.Resource;
 
 import net.shibboleth.profile.installablecomponent.InstallableComponentInfo.VersionInfo;
 import net.shibboleth.profile.plugin.Plugin;
+import net.shibboleth.shared.collection.CollectionSupport;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.primitive.LoggerFactory;
 import net.shibboleth.shared.spring.httpclient.resource.HTTPResource;
@@ -44,9 +47,8 @@ public final class InstallableComponentSupport {
     /**
      * Property Name suffix for available versions inside {@link Plugin#getUpdateURLs()}.
      * @deprecated - will be removed in V6
-     *
      */
-    @Nonnull @Deprecated(forRemoval = true, since = "5.3") 
+    @Nonnull @Deprecated(forRemoval = true, since = "5.3")
     public static final String AVAILABLE_VERSIONS_PROPERTY_SUFFIX = ".versions";
 
     /** Property Name for Download directory {@link Plugin#getUpdateURLs()}. */
@@ -61,7 +63,11 @@ public final class InstallableComponentSupport {
     /** Property Name for minimum supported IdP version inside inside {@link Plugin#getUpdateURLs()}. */
     @Nonnull public static final String MIN_IDP_VERSION_INTERFIX = ".idpVersionMin.";
 
     /** Property Name for support level inside inside {@link Plugin#getUpdateURLs()}. */
     @Nonnull public static final String SUPPORT_LEVEL_INTERFIX = ".supportLevel.";
 
     /** Used for specifying templated keynames. */
@@ -183,4 +189,23 @@ public final class InstallableComponentSupport {
         return null;
     }
 
+    /** What are the names of the InstallableComponents in the provided {@link Properties}.
+     * @param properties the input, usually parsed fron plugin.properties
+     * @return the component's names
+     */
+    @Nonnull public static List<String> getAllComponents(@Nullable final Properties properties) {
+        if (properties == null || properties.size() == 0) {
+            return CollectionSupport.emptyList();
+        }
+        final Set<String> result = new HashSet<>();
+        for (Object key : properties.keySet()) {
+            final String keyAsString = (String) key;
+            final int index = keyAsString.indexOf(SUPPORT_LEVEL_INTERFIX);
+            if (index < 0) {
+                continue;
+            }
+            result.add(keyAsString.substring(0, index));
+        }
+        return new ArrayList<String>(result);
+    }
 }
\ No newline at end of file
@@ -61,7 +63,11 @@ public final class InstallableComponentSupport {
     @Nonnull public static final String MIN_IDP_VERSION_INTERFIX = ".idpVersionMin.";
 
-    /** Property Name for support level inside inside {@link Plugin#getUpdateURLs()}. */
+    /**
+     * Property Name for support level inside inside {@link Plugin#getUpdateURLs()}.
+     * <em>NOTE</em> properties file <em>MUST</em> have lines with this suffix.
+     * It is used to derive the versions available and the plugin ids.
+     */
     @Nonnull public static final String SUPPORT_LEVEL_INTERFIX = ".supportLevel.";
 
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list